########
Wildboar
########

This is the API reference manual for `Wildboar <https://wildboar.dev>`__.

.. toctree::
  :maxdepth: 3
  :hidden:

  Install <install>
  guide
  API <api/wildboar/index>
  examples
  more/whatsnew

.. include:: api/index.rst

